<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv" sourcelanguage="en">
<context>
    <name>AboutDialogBase</name>
    <message>
        <location filename="res/AboutDialogBase.ui" line="38"/>
        <source>About Barrier</source>
        <translation>Om Barrier</translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="53"/>
        <source>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2016 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Barrier is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Barrier is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Barrier GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2016 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Barrier is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Barrier is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Barrier GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</oldsource>
        <translation>&lt;p&gt;
Program för att dela tangentbord och mus. Plattformsöverskridande och öppen källkod.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2016 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Barrier är släppt under GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Barrier baseras på CosmoSynergy av Richard Lee and Adam Feder.&lt;br /&gt;
Barrier GUI baseras på QSynergy av Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Besök vår webbplats för hjälp och information (symless.com).
&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="140"/>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="124"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="res/AboutDialogBase.ui" line="163"/>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>ActionDialogBase</name>
    <message>
        <location filename="res/ActionDialogBase.ui" line="14"/>
        <source>Configure Action</source>
        <translation>Konfigurera åtgärd</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="20"/>
        <source>Choose the action to perform</source>
        <translation>Välj den åtgärd som skall utföras</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="26"/>
        <source>Press a hotkey</source>
        <translation>Tryck ner en snabbtangent</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="36"/>
        <source>Release a hotkey</source>
        <translation>Släpp en snabbtangent</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="43"/>
        <source>Press and release a hotkey</source>
        <translation>Tryck ner och släpp en snabbtangent</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="69"/>
        <source>only on these screens</source>
        <translation>endast på dessa skärmar</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="119"/>
        <source>Switch to screen</source>
        <translation>Växla till skärm</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="150"/>
        <source>Switch in direction</source>
        <translation>Växla i riktning</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="174"/>
        <source>left</source>
        <translation>vänster</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="179"/>
        <source>right</source>
        <translation>höger</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="184"/>
        <source>up</source>
        <translation>upp</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="189"/>
        <source>down</source>
        <translation>ner</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="201"/>
        <source>Lock cursor to screen</source>
        <translation>Lås muspekaren till skärm</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="225"/>
        <source>toggle</source>
        <translation>växla</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="230"/>
        <source>on</source>
        <translation>på</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="235"/>
        <source>off</source>
        <translation>av</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="248"/>
        <source>This action is performed when</source>
        <translation>Denna åtgärd utförs när</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="254"/>
        <source>the hotkey is pressed</source>
        <translation>snabbtangenten trycks ner</translation>
    </message>
    <message>
        <location filename="res/ActionDialogBase.ui" line="264"/>
        <source>the hotkey is released</source>
        <translation>snabbtangenten släpps</translation>
    </message>
</context>
<context>
    <name>AddClientDialog</name>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="20"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="35"/>
        <source>TextLabel</source>
        <translation>Textetikett</translation>
    </message>
    <message>
        <location filename="res/AddClientDialogBase.ui" line="83"/>
        <source>Ignore auto connect clients</source>
        <translation>Ignorera klienter med automatisk anslutning</translation>
    </message>
</context>
<context>
    <name>HotkeyDialogBase</name>
    <message>
        <location filename="res/HotkeyDialogBase.ui" line="14"/>
        <source>Hotkey</source>
        <translation>Snabbtangent</translation>
    </message>
    <message>
        <location filename="res/HotkeyDialogBase.ui" line="20"/>
        <source>Enter the specification for the hotkey:</source>
        <translation>Beskriv snabbtangenten:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="790"/>
        <source>&amp;Start</source>
        <translation>&amp;Starta</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="237"/>
        <source>&amp;File</source>
        <translation>&amp;Arkiv</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="238"/>
        <source>&amp;Edit</source>
        <translation>&amp;Redigera</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="239"/>
        <source>&amp;Window</source>
        <translation>&amp;Fönster</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="240"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="364"/>
        <source>&lt;p&gt;Your version of Barrier is out of date. Version &lt;b&gt;%1&lt;/b&gt; is now available to &lt;a href=&quot;%2&quot;&gt;download&lt;/a&gt;.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;Version %1 is now available, &lt;a href=&quot;%2&quot;&gt;visit website&lt;/a&gt;.&lt;/p&gt;</oldsource>
        <translation>&lt;p&gt;Din version av Barrier är utdaterad. Version &lt;b&gt;%1&lt;/b&gt; finns nu tillgänglig för &lt;a href=&quot;%2&quot;&gt;nerladdning&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="577"/>
        <source>Program can not be started</source>
        <translation>Programmet kan inte startas</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="577"/>
        <source>The executable&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;could not be successfully started, although it does exist. Please check if you have sufficient permissions to run this program.</source>
        <translation>Programmet&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;kunde inte startas, men det finns tillgängligt. Kontrollera att du har tillräckliga rättigheter för att köra detta program.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="596"/>
        <source>Barrier client not found</source>
        <translation>Barrier-klienten hittades inte</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="597"/>
        <source>The executable for the barrier client does not exist.</source>
        <translation>Barrier-klientens körbara fil saknas.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="625"/>
        <source>Hostname is empty</source>
        <translation>Värdnamnet är tomt</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="626"/>
        <source>Please fill in a hostname for the barrier client to connect to.</source>
        <translation>Fyll i det värdnamn som Barrier-klienten skall ansluta till.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="646"/>
        <source>Cannot write configuration file</source>
        <translation>Kan inte skriva konfigurationsfilen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="646"/>
        <source>The temporary configuration file required to start barrier can not be written.</source>
        <translation>Den tillfälliga konfigurationsfil som krävs för att starta Barrier, kan inte skrivas.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="659"/>
        <source>Configuration filename invalid</source>
        <translation>Ogiltigt namn på konfigurationsfilen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="660"/>
        <source>You have not filled in a valid configuration file for the barrier server. Do you want to browse for the configuration file now?</source>
        <translation>Du har inte fyllt i en giltig konfigurationsfil för Barrier-servern. Vill du bläddra efter konfigurationsfilen nu?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="688"/>
        <source>Barrier server not found</source>
        <translation>Barrier-servern hittades inte</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="689"/>
        <source>The executable for the barrier server does not exist.</source>
        <translation>Barrier-serverns körbara fil finns inte.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="764"/>
        <source>Barrier terminated with an error</source>
        <translation>Barrier avslutades med ett fel</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="764"/>
        <source>Barrier terminated unexpectedly with an exit code of %1.&lt;br&gt;&lt;br&gt;Please see the log output for details.</source>
        <translation>Barrier avslutades oväntat med avbrottskoden %1.&lt;br&gt;&lt;br&gt;Se loggdata för detaljerad info.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="783"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1038"/>
        <source>Please add the server (%1) to the grid.</source>
        <translation>Lägg till servern (%1) i rutfältet.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1044"/>
        <source>Please drag the new client screen (%1) to the desired position on the grid.</source>
        <translation>Dra den nya klientskämen (%1) till önskad position i rutfältet.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1147"/>
        <source>Failed to detect system architecture.</source>
        <translation>Kunde inte identifiera systemarkitektur.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1165"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1189"/>
        <source>Failed to download Bonjour installer to location: %1</source>
        <translation>Kunde inte ladda ner Bonjour-installerare till platsen: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1226"/>
        <source>Do you want to enable auto config and install Bonjour?

This feature helps you establish the connection.</source>
        <translation>Vill du aktivera automatisk konfiguration och installation av Bonjour?

Denna funktion hjälper dig att etablera anslutningen.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1270"/>
        <source>Auto config feature requires Bonjour.

Do you want to install Bonjour?</source>
        <translation>Automatisk konfiguration kräver Bonjour.

Vill du installera Bonjour?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="815"/>
        <source>Barrier is starting.</source>
        <translation>Barrier startar.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="809"/>
        <source>Barrier is running.</source>
        <translation>Barrier körs.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="819"/>
        <source>Barrier is not running.</source>
        <translation>Barrier körs inte.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="870"/>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1146"/>
        <location filename="src/MainWindow.cpp" line="1225"/>
        <location filename="src/MainWindow.cpp" line="1269"/>
        <source>Barrier</source>
        <translation>Barrier</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="987"/>
        <source>Browse for a barriers config file</source>
        <translation>Bläddra efter Barriers konfigurationsfil</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="408"/>
        <source>Barrier is now connected, You can close the config window. Barrier will remain connected in the background.</source>
        <translation>Barrier är nu ansluten, du kan stänga konfigurationsfönstret. Barrier kommer att fortsätta vara ansluten i bakgrunden.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="434"/>
        <source>Security question</source>
        <translation>Säkerhetsfråga</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="435"/>
        <source>Do you trust this fingerprint?

%1

This is a server fingerprint. You should compare this fingerprint to the one on your server&apos;s screen. If the two don&apos;t match exactly, then it&apos;s probably not the server you&apos;re expecting (it could be a malicious user).

To automatically trust this fingerprint for future connections, click Yes. To reject this fingerprint and disconnect from the server, click No.</source>
        <translation>Litar du på fingeravtrycket?

%1

Detta är en servers fingeravtryck. Du bör jämföra det här fingeravtrycket med det på serverns skärm. Om de två inte stämmer exakt, så är det förmodligen inte den server du förväntar dig (det kan vara en skadlig användare).

Klicka &quot;Ja&quot; för att automatiskt lita på fingeravtrycket i framtida anslutningar. Klicka &quot;Nej&quot; för att avvisa det här fingeravtrycket och koppla från servern.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1000"/>
        <source>Save configuration as...</source>
        <translation>Spara konfigurationen som...</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1004"/>
        <source>Save failed</source>
        <translation>Kunde inte spara</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1004"/>
        <source>Could not save configuration to file.</source>
        <translation>Kunde inte spara konfigurationen till fil.</translation>
    </message>
</context>
<context>
    <name>MainWindowBase</name>
    <message>
        <location filename="res/MainWindowBase.ui" line="26"/>
        <source>Barrier</source>
        <translation>Barrier</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="90"/>
        <source>Ser&amp;ver (share this computer&apos;s mouse and keyboard):</source>
        <translation>Ser&amp;ver (dela den här datorns mus och tangentbord):</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="243"/>
        <source>Screen name:</source>
        <translation>Skärmnamn:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="257"/>
        <source>&amp;Server IP:</source>
        <translation>&amp;Serverns IP:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="380"/>
        <location filename="res/MainWindowBase.ui" line="409"/>
        <source>&amp;Start</source>
        <translation>&amp;Starta</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="181"/>
        <source>Use existing configuration:</source>
        <translation>Använd befintlig konfiguration:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="190"/>
        <source>&amp;Configuration file:</source>
        <translation>&amp;Konfigurationsfil:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="210"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Bläddra...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="147"/>
        <source>Configure interactively:</source>
        <translation>Konfigurera interaktivt:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="159"/>
        <source>&amp;Configure Server...</source>
        <translation>&amp;Konfigurera server...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="350"/>
        <source>Ready</source>
        <translation>Klar</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="296"/>
        <source>Log</source>
        <translation>Logg</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="373"/>
        <source>&amp;Reload</source>
        <translation>&amp;Uppdatera</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="107"/>
        <source>IP addresses:</source>
        <translation>IP-adresser:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="131"/>
        <source>Fingerprint:</source>
        <translation>Fingeravtryck:</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="228"/>
        <source>&amp;Client (use another computer&apos;s mouse and keyboard):</source>
        <translation>&amp;Klient (använd en annan dators mus och tangenbord):</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="270"/>
        <source>Auto config</source>
        <translation>Konfigurera automatiskt</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="390"/>
        <source>&amp;About Barrier...</source>
        <translation>&amp;Om Barrier...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="398"/>
        <source>&amp;Quit</source>
        <translation>A&amp;vsluta</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="401"/>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="412"/>
        <source>Run</source>
        <translation>Kör</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="423"/>
        <source>S&amp;top</source>
        <translation>S&amp;topp</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="426"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="434"/>
        <source>S&amp;how Status</source>
        <translation>V&amp;isa status</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="442"/>
        <source>&amp;Hide</source>
        <translation>&amp;Dölj</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="445"/>
        <source>Hide</source>
        <translation>Dölj</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="453"/>
        <source>&amp;Show</source>
        <translation>&amp;Visa</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="456"/>
        <source>Show</source>
        <translation>Visa</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="464"/>
        <source>Save configuration &amp;as...</source>
        <translation>S&amp;para konfigurationen som...</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="467"/>
        <source>Save the interactively generated server configuration to a file.</source>
        <translation>Spara den interaktivt skapade serverkonfigurationen till en fil.</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="475"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="478"/>
        <source>Edit settings</source>
        <translation>Ändra inställningar</translation>
    </message>
    <message>
        <location filename="res/MainWindowBase.ui" line="486"/>
        <source>Run Wizard</source>
        <translation>Kör guiden</translation>
    </message>
</context>
<context>
    <name>NewScreenWidget</name>
    <message>
        <location filename="src/NewScreenWidget.cpp" line="32"/>
        <source>Unnamed</source>
        <translation>Namnlös</translation>
    </message>
</context>
<context>
    <name>PluginManager</name>
    <message>
        <location filename="src/PluginManager.cpp" line="58"/>
        <source>Failed to get plugin directory.</source>
        <translation>Kunde inte hämta mappen för insticksmoduler.</translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="63"/>
        <source>Failed to get profile directory.</source>
        <translation>Kunde inte hämta profilmappen.</translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="136"/>
        <source>Failed to download plugin &apos;%1&apos; to: %2
%3</source>
        <translation>Kunde inte ladda ner insticksmodulen &quot;%1&quot; till: %2
%3</translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="167"/>
        <source>Could not get Windows architecture type.</source>
        <translation>Kunde inte hämta Windows arkitekturtyp.</translation>
    </message>
    <message>
        <location filename="src/PluginManager.cpp" line="191"/>
        <source>Could not get Linux architecture type.</source>
        <translation>Kunde inte hämta Linux arkitekturtyp.</translation>
    </message>
</context>
<context>
    <name>PluginWizardPage</name>
    <message>
        <location filename="res/PluginWizardPageBase.ui" line="14"/>
        <source>Setup Barrier</source>
        <translation>Ställ in Barrier</translation>
    </message>
    <message>
        <location filename="res/PluginWizardPageBase.ui" line="101"/>
        <source>Please wait...</source>
        <translation>Vänta...</translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="72"/>
        <source>Error: %1</source>
        <translation>Fel: %1</translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="80"/>
        <location filename="src/PluginWizardPage.cpp" line="201"/>
        <source>Setup complete.</source>
        <translation>Inställning slutförd.</translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="93"/>
        <source>Downloading &apos;%1&apos; plugin (%2/%3)...</source>
        <translation>Laddar ner &quot;%1&quot; (%2/%3)...</translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="104"/>
        <source>Plugins installed successfully.</source>
        <translation>Insticksmoduler korrekt installerade.</translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="120"/>
        <source>Generating SSL certificate...</source>
        <translation>Genererar SSL-certifikat...</translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="170"/>
        <source>Downloading plugin: %1 (1/%2)</source>
        <translation>Laddar ner insticksmodul: %1 (1/%2)</translation>
    </message>
    <message>
        <location filename="src/PluginWizardPage.cpp" line="239"/>
        <source>Getting plugin list...</source>
        <translation>Hämtar instickslista...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="src/MainWindow.cpp" line="60"/>
        <source>All files (*.*)</source>
        <translation>Alla filer (*.*)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="60"/>
        <source>Barrier Configurations (*.sgc)</source>
        <translation>Barrier-konfigurationer (*.sgc)</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="67"/>
        <source>Barrier Configurations (*.conf)</source>
        <translation>Barrier-konfigurationer (*.conf)</translation>
    </message>
    <message>
        <location filename="src/main.cpp" line="119"/>
        <source>System tray is unavailable, quitting.</source>
        <translation>Systemfältet otillgängligt, avslutar.</translation>
    </message>
</context>
<context>
    <name>ScreenSettingsDialog</name>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="67"/>
        <source>Screen name is empty</source>
        <translation>Skärmnamnet är tomt</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="68"/>
        <source>The screen name cannot be empty. Please either fill in a name or cancel the dialog.</source>
        <translation>Skärmnamnet kan inte vara tomt. Fyll i ett namn eller avbryt.</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="83"/>
        <source>Screen name matches alias</source>
        <translation>Skärmnamnet är samma som alias</translation>
    </message>
    <message>
        <location filename="src/ScreenSettingsDialog.cpp" line="84"/>
        <source>The screen name cannot be the same as an alias. Please either remove the alias or change the screen name.</source>
        <translation>Skärmnamnet kan inte vara samma som alias. Ta antingen bort alias eller ändra skärmnamnet.</translation>
    </message>
</context>
<context>
    <name>ScreenSettingsDialogBase</name>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="14"/>
        <source>Screen Settings</source>
        <translation>Skärminställningar</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="22"/>
        <source>Screen &amp;name:</source>
        <translation>Skärm&amp;namn:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="42"/>
        <source>A&amp;liases</source>
        <translation>A&amp;lias</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="57"/>
        <source>&amp;Add</source>
        <translation>&amp;Lägg till</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="74"/>
        <source>&amp;Remove</source>
        <translation>&amp;Ta bort</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="97"/>
        <source>&amp;Modifier keys</source>
        <translation>&amp;Modifieringstangenter</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="106"/>
        <source>&amp;Shift:</source>
        <translation>&amp;Shift:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="117"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="164"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="211"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="258"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="305"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="122"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="169"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="216"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="263"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="310"/>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="127"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="174"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="221"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="268"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="315"/>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="132"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="179"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="226"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="273"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="320"/>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="137"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="184"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="231"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="278"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="325"/>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="142"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="189"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="236"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="283"/>
        <location filename="res/ScreenSettingsDialogBase.ui" line="330"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="150"/>
        <source>&amp;Ctrl:</source>
        <translation>&amp;Ctrl:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="197"/>
        <source>Al&amp;t:</source>
        <translation>Al&amp;t:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="244"/>
        <source>M&amp;eta:</source>
        <translation>M%eta:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="291"/>
        <source>S&amp;uper:</source>
        <translation>S&amp;uper:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="358"/>
        <source>&amp;Dead corners</source>
        <translation>&amp;Döda hörn</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="367"/>
        <source>Top-left</source>
        <translation>Vänster överkant</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="374"/>
        <source>Top-right</source>
        <translation>Höger överkant</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="381"/>
        <source>Bottom-left</source>
        <translation>Vänster underkant</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="388"/>
        <source>Bottom-right</source>
        <translation>Höger underkant</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="397"/>
        <source>Corner Si&amp;ze:</source>
        <translation>H&amp;örnstorlek:</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="428"/>
        <source>&amp;Fixes</source>
        <translation>&amp;Korrigeringar</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="437"/>
        <source>Fix CAPS LOCK key</source>
        <translation>Korrigera CAPS LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="444"/>
        <source>Fix NUM LOCK key</source>
        <translation>Korrigera NUM LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="451"/>
        <source>Fix SCROLL LOCK key</source>
        <translation>Korrigera SCROLL LOCK</translation>
    </message>
    <message>
        <location filename="res/ScreenSettingsDialogBase.ui" line="458"/>
        <source>Fix XTest for Xinerama</source>
        <translation>Korrigera XTest för Xinerama</translation>
    </message>
</context>
<context>
    <name>ScreenSetupModel</name>
    <message>
        <location filename="src/ScreenSetupModel.cpp" line="51"/>
        <source>&lt;center&gt;Screen: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Double click to edit settings&lt;br&gt;Drag screen to the trashcan to remove it</source>
        <translation>&lt;center&gt;Skärm:&lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Dubbelklicka för att ändra inställningar&lt;br&gt;Dra skärmen till papperskorgen för att ta bort den</translation>
    </message>
</context>
<context>
    <name>ServerConfigDialog</name>
    <message>
        <location filename="src/ServerConfigDialog.cpp" line="75"/>
        <source>Configure server</source>
        <translation>Konfigurera server</translation>
    </message>
</context>
<context>
    <name>ServerConfigDialogBase</name>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="14"/>
        <source>Server Configuration</source>
        <translation>Serverkonfiguration</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="24"/>
        <source>Screens and links</source>
        <translation>Skärmar och länkar</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="35"/>
        <source>Drag a screen from the grid to the trashcan to remove it.</source>
        <translation>Dra en skärm från rutfältet till papperskorgen för att ta bort den.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="60"/>
        <source>Configure the layout of your barrier server configuration.</source>
        <translation>Konfigurera layouten på din Barrier serverkonfiguration.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="73"/>
        <source>Drag this button to the grid to add a new screen.</source>
        <translation>Dra den här knappen till rutfältet för att lägga till en ny skärm.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="128"/>
        <source>Drag new screens to the grid or move existing ones around.
Drag a screen to the trashcan to delete it.
Double click on a screen to edit its settings.</source>
        <translation>Dra nya skärmar till rutfältet eller flytta runt befintliga.
Dra en skärm till papperskorgen för att ta bort den.
Dubbelklicka på en skärm för att ändra dess inställningar.</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="157"/>
        <source>Hotkeys</source>
        <translation>Snabbtangenter</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="163"/>
        <source>&amp;Hotkeys</source>
        <translation>&amp;Snabbtangenter</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="175"/>
        <source>&amp;New</source>
        <translation>&amp;Nytt</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="185"/>
        <source>&amp;Edit</source>
        <translation>&amp;Redigera</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="195"/>
        <source>&amp;Remove</source>
        <translation>&amp;Ta bort</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="218"/>
        <source>A&amp;ctions</source>
        <translation>&amp;Åtgärder</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="230"/>
        <source>Ne&amp;w</source>
        <translation>N&amp;ytt</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="240"/>
        <source>E&amp;dit</source>
        <translation>Re&amp;digera</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="250"/>
        <source>Re&amp;move</source>
        <translation>Ta &amp;bort</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="274"/>
        <source>Advanced server settings</source>
        <translation>Avancerade serverinställningar</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="280"/>
        <source>&amp;Switch</source>
        <translation>&amp;Växla</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="291"/>
        <source>Switch &amp;after waiting</source>
        <translation>V&amp;äxla efter väntan</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="330"/>
        <location filename="res/ServerConfigDialogBase.ui" line="383"/>
        <location filename="res/ServerConfigDialogBase.ui" line="458"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="344"/>
        <source>Switch on double &amp;tap within</source>
        <translation>Växla vid &amp;dubbelklick inom</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="408"/>
        <source>&amp;Options</source>
        <translation>&amp;Alternativ</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="419"/>
        <source>&amp;Check clients every</source>
        <translation>&amp;Kontrollera klienter varje</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="470"/>
        <source>Use &amp;relative mouse moves</source>
        <translation>Använd &amp;relativa musrörelser</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="480"/>
        <source>S&amp;ynchronize screen savers</source>
        <translation>Synkr&amp;onisera skärmsläckare</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="490"/>
        <source>Don&apos;t take &amp;foreground window on Windows servers</source>
        <translation>Använd inte &amp;förgrundsfönster på Windowsservrar</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="510"/>
        <source>Ignore auto config clients</source>
        <translation>Ignorera automatiskt konfigurerade klienter</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="520"/>
        <source>&amp;Dead corners</source>
        <translation>&amp;Döda hörn</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="529"/>
        <source>To&amp;p-left</source>
        <translation>V&amp;änster överkant</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="536"/>
        <source>Top-rig&amp;ht</source>
        <translation>H&amp;öger överkant</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="543"/>
        <source>&amp;Bottom-left</source>
        <translation>Vänster &amp;underkant</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="550"/>
        <source>Bottom-ri&amp;ght</source>
        <translation>Höger u&amp;nderkant</translation>
    </message>
    <message>
        <location filename="res/ServerConfigDialogBase.ui" line="572"/>
        <source>Cor&amp;ner Size:</source>
        <translation>Hö&amp;rnstorlek:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="src/SettingsDialog.cpp" line="131"/>
        <source>Save log file to...</source>
        <translation>Spara loggfil till...</translation>
    </message>
    <message>
        <location filename="src/SettingsDialog.cpp" line="151"/>
        <source>Elevate Barrier</source>
        <translation>Höj Barriers behörighet</translation>
    </message>
    <message>
        <location filename="src/SettingsDialog.cpp" line="152"/>
        <source>Are you sure you want to elevate Barrier?

This allows Barrier to interact with elevated processes and the UAC dialog, but can cause problems with non-elevated processes. Elevate Barrier only if you really need to.</source>
        <translation>Vill du verkligen höja Barriers behörighet?
Detta låter Barrier interagera med förhöjda processer och UAC-dialogen, men kan skapa program med processer som inte är förhöjda. Höj Barriers behörighet enbart om du verkligen måste.</translation>
    </message>
</context>
<context>
    <name>SettingsDialogBase</name>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="14"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="32"/>
        <source>Sc&amp;reen name:</source>
        <translation>Sk&amp;ärmnamn:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="49"/>
        <source>P&amp;ort:</source>
        <translation>P&amp;ort:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="78"/>
        <source>&amp;Interface:</source>
        <translation>G&amp;ränssnitt:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="120"/>
        <source>Elevate mode</source>
        <translation>Rättighetsläge</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="127"/>
        <source>&amp;Hide on startup</source>
        <translation>&amp;Dölj vid programstart</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="146"/>
        <source>&amp;Network Security</source>
        <translation>&amp;Nätverkssäkerhet</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="155"/>
        <source>Use &amp;SSL encryption (unique certificate)</source>
        <translation>Använd &amp;SSL-kryptering (unikt certifikat)</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="184"/>
        <source>Logging</source>
        <translation>Loggning</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="202"/>
        <source>&amp;Logging level:</source>
        <translation>&amp;Loggningsnivå:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="251"/>
        <source>Log to file:</source>
        <translation>Logga till fil:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="268"/>
        <source>Browse...</source>
        <translation>Bläddra...</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="213"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="107"/>
        <source>&amp;Language:</source>
        <translation>&amp;Språk:</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="20"/>
        <source>&amp;Miscellaneous</source>
        <translation>&amp;Diverse</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="218"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="223"/>
        <source>Note</source>
        <translation>Anteckning</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="228"/>
        <source>Info</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="233"/>
        <source>Debug</source>
        <translation>Felsök</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="238"/>
        <source>Debug1</source>
        <translation>Felsök1</translation>
    </message>
    <message>
        <location filename="res/SettingsDialogBase.ui" line="243"/>
        <source>Debug2</source>
        <translation>Felsök2</translation>
    </message>
</context>
<context>
    <name>SetupWizard</name>
    <message>
        <location filename="src/SetupWizard.cpp" line="72"/>
        <source>Setup Barrier</source>
        <translation>Ställ in Barrier</translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="113"/>
        <source>Please select an option.</source>
        <translation>Välj ett alternativ.</translation>
    </message>
    <message>
        <location filename="src/SetupWizard.cpp" line="80"/>
        <source>Please enter your email address and password.</source>
        <translation>Ange din e-postadress och lösenord.</translation>
    </message>
</context>
<context>
    <name>SetupWizardBase</name>
    <message>
        <location filename="res/SetupWizardBase.ui" line="26"/>
        <source>Setup Barrier</source>
        <translation>Installera Barrier</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="30"/>
        <source>Welcome</source>
        <translation>Välkommen</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="39"/>
        <source>Thanks for installing Barrier!</source>
        <translation>Tack för att du installerar Barrier!</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="114"/>
        <source>Barrier lets you easily share your mouse and keyboard between multiple computers on your desk, and it&apos;s Free and Open Source. Just move your mouse off the edge of one computer&apos;s screen on to another. You can even share all of your clipboards. All you need is a network connection. Barrier is cross-platform (works on Windows, Mac OS X and Linux).</source>
        <translation>Med Barrier kan du enkelt dela din mus och ditt tangentbord mellan flera datorer på ditt skrivbord, och det är fri och öppen källkod. För bara muspekaren över kanten på en datorskärm till en annan. Du kan till och med dela urklipp. Allt du behöver är en nätverksanslutning. Barrier är multiplattform (fungerar på både Windows, OSX och Linux).</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="125"/>
        <source>Activate</source>
        <translation>Aktivera</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="131"/>
        <source>&amp;Activate now...</source>
        <translation>&amp;Aktivera nu...</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="152"/>
        <source>Email:</source>
        <translation>E-post:</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="178"/>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="204"/>
        <source>&lt;a href=&quot;https://symless.com/account/reset/&quot;&gt;Forgot password&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://symless.com/account/reset/&quot;&gt;Glömt lösenord&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="232"/>
        <source>&amp;Skip activation</source>
        <translation>&amp;Skippa aktivering</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="277"/>
        <source>&amp;Server (share this computer&apos;s mouse and keyboard)</source>
        <translation>&amp;Server (dela denna dators mus och tangentbord)</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="290"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;My main mouse and keyboard are connected to this computer. This will allow you to move your mouse over to another computer&apos;s screen. There can only be one server in your setup.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Min primära mus och tangentbord är anslutna till den här datorn. Detta låter dig flytta musen över till en annan dators skärm. Det kan bara finnas en server i din installation.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="326"/>
        <source>&amp;Client (use another computer&apos;s mouse and keyboard)</source>
        <translation>&amp;Klient (använd en annan dators mus och tangentbord)</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="339"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;You have already set up a server. This computer will be controlled using the server&apos;s mouse and keyboard. There can be many clients in your setup.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Du har redan installerat en server. Den här datorn styrs med hjälp av serverns mus och tangentbord. Det kan finnas många klienter i din installation.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="res/SetupWizardBase.ui" line="262"/>
        <source>Server or Client?</source>
        <translation>Server eller klient?</translation>
    </message>
</context>
<context>
    <name>SslCertificate</name>
    <message>
        <location filename="src/SslCertificate.cpp" line="42"/>
        <source>Failed to get profile directory.</source>
        <translation>Kunde inte hämta profilmappen.</translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="141"/>
        <source>SSL certificate generated.</source>
        <translation>SSL-certifikat genererat.</translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="170"/>
        <source>SSL fingerprint generated.</source>
        <translation>SSL-fingeravtryck genererat.</translation>
    </message>
    <message>
        <location filename="src/SslCertificate.cpp" line="173"/>
        <source>Failed to find SSL fingerprint.</source>
        <translation>Kunde inte hitta SSL-fingeravtryck.</translation>
    </message>
</context>
<context>
    <name>VersionChecker</name>
    <message>
        <location filename="src/VersionChecker.cpp" line="102"/>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
</context>
<context>
    <name>WebClient</name>
    <message>
        <location filename="src/WebClient.cpp" line="44"/>
        <source>An error occurred while trying to sign in. Please contact the helpdesk, and provide the following details.

%1</source>
        <translation>Ett fel uppstod när du försökte logga in. Kontakta supporten och ange följande uppgifter.

%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="65"/>
        <source>Login failed, invalid email or password.</source>
        <translation>Inloggning misslyckades. Ogiltig e-postaddress eller lösenord.</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="78"/>
        <source>Login failed, an error occurred.

%1</source>
        <translation>Inloggning misslyckades. Ett fel uppstod.

%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="86"/>
        <source>Login failed, an error occurred.

Server response:

%1</source>
        <translation>Inloggning misslyckades. Ett fel uppstod.

Serversvar:

%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="101"/>
        <source>An error occurred while trying to query the plugin list. Please contact the help desk, and provide the following details.

%1</source>
        <translation>Ett fel uppstod när instickslistan anropades. Kontakta supporten och ange följande uppgifter.

%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="120"/>
        <source>Get plugin list failed, invalid user email or password.</source>
        <translation>Kunde inte hämta instickslistan. Ogiltig e-postadress eller lösenord.</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="131"/>
        <source>Get plugin list failed, an error occurred.

%1</source>
        <translation>Kunde inte hämta instickslistan. Ett fel uppstod.

%1</translation>
    </message>
    <message>
        <location filename="src/WebClient.cpp" line="137"/>
        <source>Get plugin list failed, an error occurred.

Server response:

%1</source>
        <translation>Kunde inte hämta instickslistan. Ett fel uppstod.

Serversvar:

%1</translation>
    </message>
</context>
<context>
    <name>ZeroconfService</name>
    <message>
        <location filename="src/ZeroconfService.cpp" line="82"/>
        <source>zeroconf server detected: %1</source>
        <translation>zeroconf-server identifierad: %1</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="91"/>
        <source>zeroconf client detected: %1</source>
        <translation>zeroconf-klient identifierad: %1</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="99"/>
        <location filename="src/ZeroconfService.cpp" line="130"/>
        <source>Zero configuration service</source>
        <translation>Zero konfigurationstjänst</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="100"/>
        <source>Error code: %1.</source>
        <translation>Felkod:%1.</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="131"/>
        <source>Unable to start the zeroconf: %1.</source>
        <translation>Kunde inte starta zeroconf: %1.</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="140"/>
        <source>Barrier</source>
        <translation>Barrier</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="141"/>
        <source>Failed to get local IP address. Please manually type in server address on your clients</source>
        <translation>Kunde inte inhämta lokal IP-adress. Skriv in serveradressen manuellt, på dina klienter.</translation>
    </message>
    <message>
        <location filename="src/ZeroconfService.cpp" line="147"/>
        <location filename="src/ZeroconfService.cpp" line="154"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>
